guessica

package module
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 4, 2021 License: MIT Imports: 12 Imported by: 2

README

Guessica

Build Go Report Card License

Update a PKGBUILD file by guessing the latest version number and finding the latest git tag and hash online.

logo

Installation (development version)

go get -u github.com/xyproto/guessica/cmd/guessica

Usage

Try to detect the latest version
guessica PKGBUILD
Try to detect the latest version and write the changes back to the PKGBUILD
guessica -i PKGBUILD

Note

The pkgver and source arrays will be guessed by searching the project webpage as defined by the url. For for projects on GitHub, github.com may also be visited.

General info

Documentation

Index

Constants

const VersionString = "Guessica 1.0.0"

VersionString contains the name and current version of Guessica

Variables

This section is empty.

Functions

func GuessSourceString

func GuessSourceString(pkgbuildContents, commonGitServer string) (string, string, error)

GuessSourceString is the function that is meant to be used from this source file It takes the contents of a PKGBUILD file and returns a new "source=" string. The new version number is guessed after looking online for a newer source. The git commit is included in the "source=" string, if possible. Returns the new pkgver and the new source. commonGitServer is often set to ie. "github.com"

Types

This section is empty.

Directories

Path Synopsis
cmd
guessica command

Jump to