Documentation
¶
Index ¶
Constants ¶
const VersionString = "Guessica 1.0.0"
VersionString contains the name and current version of Guessica
Variables ¶
This section is empty.
Functions ¶
func GuessSourceString ¶
GuessSourceString is the function that is meant to be used from this source file It takes the contents of a PKGBUILD file and returns a new "source=" string. The new version number is guessed after looking online for a newer source. The git commit is included in the "source=" string, if possible. Returns the new pkgver and the new source. commonGitServer is often set to ie. "github.com"
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.