guessica

package module
v0.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 28, 2020 License: MIT Imports: 12 Imported by: 2

README

Guessica Build Status Go Report Card License

Update a PKGBUILD file by guessing the latest version number and finding the latest git tag and hash online.

logo

Installation (development version)

go get -u github.com/xyproto/guessica/cmd/guessica

Usage

guessica PKGBUILD

Note

The pkgver and source arrays will be guessed by searching the project webpage as defined by the url. For for projects on GitHub, github.com may also be visited.

Updating a PKGBUILD may or may not work. guessica will be doing its best, by guessing. Take a backup of your PKGBUILD first, if you need to.

General info

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GuessSourceString

func GuessSourceString(pkgbuildContents string) (string, string, error)

GuessSourceString is the function that is meant to be used from this source file It takes the contents of a PKGBUILD file and returns a new "source=" string. The new version number is guessed after looking online for a newer source. The git commit is included in the "source=" string, if possible. Returns the new pkgver and the new source.

Types

This section is empty.

Directories

Path Synopsis
cmd
guessica command

Jump to