Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GuessSourceString ¶
GuessSourceString is the function that is meant to be used from this source file It takes the contents of a PKGBUILD file and returns a new "source=" string. The new version number is guessed after looking online for a newer source. The git commit is included in the "source=" string, if possible. Returns the new pkgver and the new source.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.